A wrapper around the /usr/bin/tput command, used to obtain terminal control sequences for moving the cursor,
clearing lines, and so forth.
A wrapper around the `/usr/bin/tput` command, used to obtain terminal control sequences for moving the cursor, clearing lines, and so forth.
Terminal width as defined by Babashka CLI.
Terminal width as defined by Babashka CLI.
Runs the tput command to convert the opcodes and values to a terminal
command string. Results are memoized.
Runs the `tput` command to convert the opcodes and values to a terminal command string. Results are memoized.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |